<?php

declare(strict_types=1);

namespace Drupal\entity_display_mode\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Define the entity display mode check route
 */
final class EntityDisplayModeCheckRoute extends Event {

  /**
   * Define the event name.
   */
  public const EVENT_NAME = 'check_route';

  /**
   * @var bool
   */
  private bool $verdict = false;

  /**
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  private RouteMatchInterface $route;

  /**
   * The class constructor.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route
   *   The route match instance.
   */
  public function __construct(RouteMatchInterface $route) {
    $this->route = $route;
  }

  /**
   * Get the route instance.
   *
   * @return \Drupal\Core\Routing\RouteMatchInterface
   *   The route match instance.
   */
  public function getRoute(): RouteMatchInterface {
    return $this->route;
  }

  /**
   * Set the entity display mode event verdict.
   *
   * @param bool $verdict
   *   The event verdict.
   */
  public function setVerdict(bool $verdict): void {
    $this->verdict = $verdict;
  }

  /**
   * Get entity display mode access verdict.
   *
   * @return bool
   */
  public function verdict(): bool {
    return $this->verdict;
  }
}
