<?php

namespace Drupal\entity_display_mode\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Define the entity display mode select widget.
 *
 * @FieldWidget(
 *   id = "entity_display_mode_select",
 *   label = @Translation("Select"),
 *   description = @Translation("Select an entity view mode."),
 *   field_types = {
 *     "entity_display_mode"
 *   }
 * )
 */
class EntityDisplayModeSelectWidget extends EntityDisplayModeBaseWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(
    FieldItemListInterface $items,
    $delta,
    array $element,
    array &$form,
    FormStateInterface $form_state
  ): array {
    $item = $items[$delta]->isEmpty() ? NULL : $items[$delta];

    $elements['value'] = [
      '#type' => 'select',
      '#options' => $this->getDisplayModeOptions(),
    ] + $element;

    if ($item instanceof FieldItemInterface) {
      $elements['value']['#default_value'] = $item->get('value')->getValue() ?? NULL;
    }

    return $elements;
  }
}
